program test
#include "petsc/finclude/petscdmplex.h"
#include "petsc/finclude/petscdmlabel.h"
 use petscdmplex
 use petscsys

 implicit none

 DM                                :: dm          ! original dm
 DM                                :: dm_geom     ! cloned dm for metrics
 PetscMPIInt                       :: myid, nproc ! MPI indices
 PetscErrorCode                    :: ierr
 character(len=PETSC_MAX_PATH_LEN) :: OutStr

 ! initialize petsc : This section also initializes MPI
 call PetscInitialize(PETSC_NULL_CHARACTER, ierr)
 if(ierr.ne.0) then
   write(*,*) 'Fail to initialize PETSc ...'
   stop
 endif

 ! get MPI size info 
 call MPI_COMM_RANK(MPI_COMM_WORLD, myid, ierr)
 call MPI_COMM_SIZE(MPI_COMM_WORLD, nproc, ierr)
 write(*,*) 'MPI information ... ', myid, nproc

 ! create mesh by default PETSc function
 call DMCreate(PETSC_COMM_WORLD, dm, ierr);CHKERRA(ierr)
 call DMSetType(dm, DMPLEX, ierr);CHKERRA(ierr)
 call DMSetFromOptions(dm, ierr);CHKERRA(ierr)
 !call DMViewFromOptions(dm, PETSC_NULL_VEC, '-dm_view', ierr);CHKERRA(ierr)
 call DMViewFromOptions(dm, PETSC_NULL_VEC, '-over_dm_view', ierr);CHKERRA(ierr)
 call DMClone(dm, dm_geom, ierr);CHKERRA(ierr)
 call PetscObjectSetName(dm_geom, 'DMPlexTest', ierr);CHKERRA(ierr)

 call DMDestroy(dm, ierr);CHKERRA(ierr)
 call DMDestroy(dm_geom, ierr);CHKERRA(ierr)

 ! finalize petsc
 write(OutStr,*) 'done ...', myid, '\n'
 call PetscPrintf(PETSC_COMM_SELF, OutStr, ierr);CHKERRA(ierr) 
 call PetscFinalize(ierr)

 stop
end program test
